/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo;

import java.io.PrintWriter;
import java.sql.Connection;
import java.sql.Driver;
import java.sql.SQLException;
import java.util.Properties;

import javax.sql.DataSource;

import kr.kangwoo.util.MessageUtils;

public class SimpleDataSource implements DataSource {

	private Driver driver;
	private String url;
	private Properties info;
	
	private PrintWriter out;
	private int loginTimeout;
	
	public SimpleDataSource(String driverClass, String url, String user,
			String password) throws SQLException {
		try {
			Class<?> clazz = Class.forName(driverClass);
			driver = (Driver)clazz.newInstance();
			
			this.url = url;
			this.info = new Properties();
			if (user != null) {
				this.info.put("user", user);	 //$NON-NLS-1$
			}
			if (password != null) {
				this.info.put("password", password);	 //$NON-NLS-1$
			}
		} catch (Exception e) {
			throw (SQLException)new SQLException(Messages.getString("SimpleDataSource.INIT_ERROR")).initCause(e); //$NON-NLS-1$
		}
	}

	public Connection getConnection() throws SQLException {
		Connection conn = driver.connect(url, info);
		conn.setAutoCommit(false);
		return conn;
	}

	public Connection getConnection(String username, String password)
			throws SQLException {
		Properties info = new Properties();
		if (username != null) {
			info.put("user", username);	 //$NON-NLS-1$
		}
		if (password != null) {
			info.put("password", password);	 //$NON-NLS-1$
		}
		return driver.connect(url, info);
	}

	public PrintWriter getLogWriter() throws SQLException {
		return out;
	}

	public void setLogWriter(PrintWriter out) throws SQLException {
		this.out = out;
	}

	public int getLoginTimeout() throws SQLException {
		return loginTimeout;
	}

	public void setLoginTimeout(int seconds) throws SQLException {
		this.loginTimeout = seconds;
	}

	public boolean isWrapperFor(Class<?> iface) throws SQLException {
		return false;
	}

	public <T> T unwrap(Class<T> iface) throws SQLException {
		throw new SQLException(MessageUtils.format(Messages.getString("SimpleDataSource.NOT_SUPPORTED"), iface.getName())); //$NON-NLS-1$
	}

}
