/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.config;

import java.net.URL;

import kr.kangwoo.damo.Messages;
import kr.kangwoo.util.BeanUtils;
import kr.kangwoo.util.MessageUtils;
import kr.kangwoo.util.StringUtils;
import kr.kangwoo.util.logging.Logger;
import kr.kangwoo.util.logging.LoggerFactory;


public class DamoConfigLoader {

	private static Logger logger = LoggerFactory.getLogger(DamoConfigLoader.class);
	
	private static IDamoConfig damoConfig;

	public synchronized static IDamoConfig getDamoConfig() {
		if (damoConfig == null) {
			String damoConfigClassName = System.getProperty("DamoConfig"); //$NON-NLS-1$
			if (StringUtils.isNotBlank(damoConfigClassName)) {
				logger.info(MessageUtils.format(Messages.getString("DamoConfigLoader.USE_CONFIG_CLASS"), damoConfigClassName)); //$NON-NLS-1$
				try {
					damoConfig = (IDamoConfig)BeanUtils.newInstance(Class.forName(damoConfigClassName));
				} catch (Exception e) {
					logger.error(MessageUtils.format(Messages.getString("DamoConfigLoader.INSTANTIATION_EXCEPTION"), damoConfigClassName)); //$NON-NLS-1$
				}
			} else {
				URL url = DamoConfig.class.getResource("/damo.xml"); //$NON-NLS-1$
				if (url != null) {

				} else {
					url = DamoConfig.class.getResource("/damo.properties"); //$NON-NLS-1$
					if (url != null) {
						damoConfig = new DamoConfig(url);
					}
				}
			}
			
			if (damoConfig == null) {
				damoConfig = new DamoConfig();
				logger.warn(Messages.getString("DamoConfigLoader.ERROR_DAMO_CONFIG")); //$NON-NLS-1$
			}
		}
		return damoConfig;
	}
}
