/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine;

import java.sql.SQLException;

import kr.kangwoo.damo.engine.batch.BatchCallback;
import kr.kangwoo.damo.engine.batch.BatchResult;

/**
 * 배치(Batch) 실행 서비스를 구현하고 있다.
 * 
 * 
 * <pre>
 * RunnableQuery query = ...;
 * IBatchService batchService = ...;
 * batchService.executeBatch(new BatchCallback() {
 * 	public BatchResult doIteration(BatchContext batchContext) throws SQLException {
 * 	BatchResult result = new BatchResult(query);
 * 	Entity entity;
 * 	for (int i = 0 ; i < size; i++) {
 * 		entity = new Entity();
 * 		entity.setNo(i);
 * 		batchContext.addBatch(query, entity);
 * 	}
 * 	result.addUpdateCounts(batchContext.executeBatch(query));
 * 	return result;
 * 	}
 * });
 * </pre>
 * 
 * @author badnom
 * @author agoodguy
 *
 */
public interface IBatchService {
	
	/**
	 * <p>배치 작업을 실행한다.</p>
	 * 
	 * @param batchCallback 배치 콜백
	 * @return 배치 처리 결과
	 * @throws SQLException
	 */
	BatchResult executeBatch(BatchCallback batchCallback) throws SQLException;
}
