/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine;

import java.sql.SQLException;

import kr.kangwoo.damo.engine.query.Query;
import kr.kangwoo.damo.engine.query.result.RowHandler;

/**
 * 쿼리 실행 서비스를 정의하고 있다.
 * 
 * @author badnom
 * @author agoodguy
 *
 */
public interface IExecuteService {

	/**
	 * <p>INSERT/UPDATE/DELETE 쿼리를 실행한다.</p>
	 * 
	 * @param query 실행할 쿼리
	 * @param parameterObject 파라메터 객체
	 * @return
	 * @throws SQLException
	 */
	int executeUpdate(Query query, Object parameterObject) throws SQLException;
	
	/**
	 * <p>SELECT 쿼리를 실행한다.</p>
	 * 
	 * @param query 실행할 쿼리
	 * @param parameterObject 파라메터 객체
	 * @param resultClass 결과값을 담을 클래스 유형
	 * @param rowHandler 결과들을 처리할 핸들러
	 * @throws SQLException
	 */
	<E> void executeQuery(Query query, Object parameterObject, Class<E> resultClass, RowHandler<E> rowHandler) throws SQLException;
	
	/**
	 * <p>SELECT 쿼리를 자동으로 페이징(Paging) 처리하여 실행한다.</p>
	 * 
	 * @param query 실행할 쿼리
	 * @param parameterObject 파라메터 객체
	 * @param resultClass 결과값을 담을 클래스 유형
	 * @param rowHandler 결과들을 처리할 핸들러
	 * @param pageNo 페이지 번호 (1부터 시작한다.)
	 * @param pageSize 페이지 크기 (0보다 커야한다.)
	 * @throws SQLException
	 */
	<E> void executeQuery(Query query, Object parameterObject, Class<E> resultClass, RowHandler<E> rowHandler, int pageNo, int pageSize) throws SQLException;
	
	/**
	 * <p>프로시저를 실행한다.</p>
	 * 
	 * @param query 실행할 쿼리
	 * @param parameterObject 파라메터 객체
	 * @param resultClass 결과값을 담을 클래스 유형
	 * @return
	 * @throws SQLException
	 */
	<E> E executeCallable(Query query, Object parameterObject, Class<E> resultClass) throws SQLException;
	
}
