/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine;

import javax.sql.DataSource;

import kr.kangwoo.damo.SessionProvider;
import kr.kangwoo.damo.engine.cache.CacheProvider;
import kr.kangwoo.damo.engine.executor.QueryExecutor;
import kr.kangwoo.damo.engine.provider.QueryProvider;
import kr.kangwoo.damo.engine.transaction.TransactionManager;

/**
 * 영속성 서비스를 정의하고 있다.
 * 
 * @author badnom
 * @author agoodguy
 *
 */
public interface IPersistenceService {

	/**
	 * <p>세션 제공자를 가져온다.</p>
	 * @return 세션 제공자
	 */
	SessionProvider getSessionProvider();
	
	/**
	 * <p>데이터 소스를 가져온다.</p>
	 * @return 데이터 소스
	 */
	DataSource getDataSource();
	
	/**
	 * <p>캐시 제공자를 가져온다.</p>
	 * @return 캐시 제공자
	 */
	CacheProvider getCacheProvider();
	
	/**
	 * <p>쿼리 제공자를 가져온다.</p>
	 * @return 쿼리 제공자
	 */
	QueryProvider getQueryProvider();
	
	/**
	 * <p>쿼리 실행자를 가져온다.</p>
	 * @return 쿼리 실행자
	 */
	QueryExecutor getQueryExecutor();
	
	/**
	 * <p>트랜잭션 관리자를 가져온다.</p>
	 * @return 트랜잭션 관리자
	 */
	TransactionManager getTransactionManager();
	
}
