/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine;

import java.sql.Connection;
import java.sql.SQLException;

/**
 * 트랜잭션 서비스를 정의하고 있다.
 * 
 * @author badnom
 * @author agoodguy
 *
 */
public interface ITransactionService {

	/**
	 * <p>트랜잭션을 시작한다.</p>
	 * 
	 * @throws SQLException 트랜잭션을 시작할 수 없을 경우 발생한다.
	 */
	void beginTransaction() throws SQLException;
	
	/**
	 * <p>트랜잭션을 시작한다.</p>
	 * 
	 * @param transactionIsolationLevel
	 * @throws SQLException
	 */
	void beginTransaction(int transactionIsolationLevel) throws SQLException;
	
	/**
	 * <p>커밋한다.</p>
	 * 
	 * @throws SQLException
	 */
	void commitTransaction() throws SQLException;
	
	/**
	 * <p>롤백한다.</p>
	 * 
	 * @throws SQLException
	 */
	void rollbackTransaction() throws SQLException;
	
	/**
	 * <p>트랙잭션을 종료한다.</p>
	 * @throws SQLException
	 */
	void endTransaction() throws SQLException;

	/**
	 * <p>현재 사용중이 커넥션을 가져온다.</p>
	 * @return
	 * @throws SQLException
	 */
	Connection getCurrentConnection() throws SQLException;
	
	/**
	 * <p>사용자 커넥션을 사용하드록 설정한다.</p>
	 * 
	 * @param conn 사용자 커넥션
	 * @throws SQLException
	 */
	void setUserConnection(Connection conn) throws SQLException;
}
