/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.cache;

import java.sql.SQLException;
import java.util.List;

import kr.kangwoo.damo.Session;
import kr.kangwoo.damo.engine.query.Query;

/**
 * 캐시 제공자를 정의하고 있다.
 * @author badnom
 * @author agoodguy
 *
 */
public interface CacheProvider {

	/**
	 * <p>쿼리에서 사용하는 캐시 대상을 삭제한다.</p>
	 * @param query
	 * @param parameterObject
	 */
	void clearCache(Query query, Object parameterObject);

	/**
	 * <p>캐시한 데이터를 가져온다.</p>
	 * 
	 * @param session
	 * @param query
	 * @param cacheKey
	 * @param resultClass
	 * @return
	 * @throws SQLException
	 */
	<E> List<E> getCachedList(Session session, Query query, CacheKey cacheKey, Class<E> resultClass) throws SQLException;
	
	/**
	 * <p>캐시한 데이터를 가져온다.</p>
	 * 
	 * @param session
	 * @param query
	 * @param cacheKey
	 * @param resultClass
	 * @param pageNo
	 * @param pageSize
	 * @return
	 * @throws SQLException
	 */
	<E> List<E> getCachedList(Session session, Query query, CacheKey cacheKey, Class<E> resultClass, int pageNo, int pageSize) throws SQLException;

}
