/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.cache;

import java.sql.SQLException;
import java.util.List;

import kr.kangwoo.damo.Messages;
import kr.kangwoo.damo.Session;
import kr.kangwoo.damo.engine.query.Query;
import kr.kangwoo.util.logging.Logger;
import kr.kangwoo.util.logging.LoggerFactory;

/**
 * 더미(Dummy)용 캐시 제공자이다.
 * 캐시 제공자가 정상적으로 초기화되지 못했을 경우 사용을 하고 있으며, 
 * 캐시 요청이 있을경우 경로 레벨로 로그를 출력해주는 역할을 하고 있다.
 * 
 * @author badnom
 *
 */
public class DummyCacheProvider implements CacheProvider {

	private Logger logger = LoggerFactory.getLogger(getClass());
	
	private static final DummyCacheProvider dummyCacheProvider = new DummyCacheProvider();
	
	public DummyCacheProvider() {
	}
	
	public static DummyCacheProvider getInstance() {
		return dummyCacheProvider;
	}
	

	public void clearCache(Query query, Object parameterObject) {
		logger.warn(Messages.getString("DummyCacheProvider.CACH_PROVIDER_NOT_INITED")); //$NON-NLS-1$
	}

	public <E> List<E> getCachedList(Session session, Query query, CacheKey cacheKey, Class<E> resultClass) throws SQLException {
		logger.warn(Messages.getString("DummyCacheProvider.CACH_PROVIDER_NOT_INITED")); //$NON-NLS-1$
		return (List<E>)session.getList(query, cacheKey.getParameterObject(), resultClass);
	}

	public <E> List<E> getCachedList(Session session, Query query, CacheKey cacheKey, Class<E> resultClass, int pageNo, int pageSize) throws SQLException {
		logger.warn(Messages.getString("DummyCacheProvider.CACH_PROVIDER_NOT_INITED")); //$NON-NLS-1$
		return (List<E>)session.getList(query, cacheKey.getParameterObject(), resultClass, pageNo, pageSize);
	}

}
