/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.executor.interceptor;

import java.sql.Connection;
import java.sql.SQLException;

import kr.kangwoo.damo.Session;
import kr.kangwoo.damo.engine.query.RunnableQuery;

/**
 * 쿼리 실행 이벤트 처리기이다.
 * 
 * @author badnom
 *
 */
public interface ExecuteInterceptor {
	
	/**
	 * <p>쿼리가 실행되기 이전에 처리할 작업을 구현한다.</p>
	 * 
	 * @param session
	 * @param conn
	 * @param runnableQuery
	 * @param parameterObject
	 * @throws SQLException
	 */
	void beforeExecute(Session session, Connection conn, RunnableQuery runnableQuery,
			Object parameterObject) throws SQLException;
	
	/**
	 * <p>쿼리가 실행된 이후에 처리할 작업을 구현한다.</p>
	 * 
	 * @param session
	 * @param conn
	 * @param runnableQuery
	 * @param parameterObject
	 * @param resultObject
	 * @throws SQLException
	 */
	void afterExecute(Session session, Connection conn, RunnableQuery runnableQuery,
			Object parameterObject, Object resultObject) throws SQLException;

}
