/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.provider.loader.file;

import java.io.File;
import java.util.Map;

import kr.kangwoo.damo.DamoException;
import kr.kangwoo.damo.Messages;
import kr.kangwoo.damo.engine.query.Query;
import kr.kangwoo.util.MessageUtils;
import kr.kangwoo.util.logging.Logger;
import kr.kangwoo.util.logging.LoggerFactory;
import kr.kangwoo.util.xml.XmlUtils;

public class QueryFile {

	private Logger logger = LoggerFactory.getLogger(QueryFile.class);
	
	private File file;
	private long lastModified;
	private Map<String, Query> queryMap;
	
	public QueryFile(File file) {
		this.file = file;
	}
	
	public boolean isModified() {
		return lastModified != file.lastModified();
	}
	
	public Map<String, Query> getQueryMap() throws DamoException {
		if (queryMap == null || isModified()) {
			queryMap = loadQueryMap();
		}
			
		return queryMap;
	}
	
	public File getFile() {
		return file;
	}
	
	@SuppressWarnings("unchecked")
	private Map<String, Query> loadQueryMap() throws DamoException {
		lastModified = file.lastModified();
		Map<String, Query> newQueryMap = null;
		try {
			QueryMapParser parser = new QueryMapParser();
			XmlUtils.getSAXParser().parse(file, parser);
			newQueryMap = (Map<String, Query>)parser.getResult();
			if (logger.isInfoEnabled()) {
				logger.info(MessageUtils.format(Messages.getString("QueryFile.PARSE_SUCCESS"), file)); //$NON-NLS-1$
			}
			if (logger.isDebugEnabled()) {
				if (newQueryMap != null) {
					for (String id : newQueryMap.keySet()) {
						logger.debug(MessageUtils.format(Messages.getString("QueryFile.QUERY_LOADED"), id, newQueryMap.get(id)));						 //$NON-NLS-1$
					}
				}
			}
		} catch (Exception e) {
			throw new DamoException(MessageUtils.format(Messages.getString("QueryFile.PARSE_ERROR"), file), e); //$NON-NLS-1$
		}
		return newQueryMap;
	}
}
