/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.provider.loader.file;

import java.sql.SQLException;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.atomic.AtomicReference;

import kr.kangwoo.damo.DamoException;
import kr.kangwoo.damo.Messages;
import kr.kangwoo.damo.engine.query.Query;
import kr.kangwoo.util.MessageUtils;

public class ReloadableQueryFileLoader extends QueryFileLoader {

	private final AtomicReference<Map<String, Query>> queryMapRef = new AtomicReference<Map<String, Query>>();
	private final Object lock = new Object();
	private int reloadSeconds;
	
	public ReloadableQueryFileLoader() {
	}

	public int getReloadSeconds() {
		return reloadSeconds;
	}

	public void setReloadSeconds(int cacheSeconds) {
		this.reloadSeconds = cacheSeconds;
	}

	protected Map<String, Query> loadQueryMap() throws DamoException {
		Map<String, Query> queryMap = new HashMap<String, Query>();
		if (queryFiles != null) {
			for (QueryFile queryMapper : queryFiles) {
				Map<String, Query> map = queryMapper.getQueryMap();
				if (map != null) {
					for (String queryId : map.keySet()) {
						if (queryMap.containsKey(queryId)) {
							throw new DamoException(MessageUtils.format(Messages.getString("ReloadableQueryFileLoader.DUPLICATED_QUERY_ID"), queryMapper.getFile(), queryId)); //$NON-NLS-1$
						}
						queryMap.put(queryId, map.get(queryId));
					}
				}
			}
		}
		return queryMap;
	}
	
	public Query getQuery(String queryId) throws SQLException {
		Map<String, Query> queryMap = queryMapRef.get();
		if (queryMap == null) {
			synchronized(lock) {
				queryMap = queryMapRef.get();
				if (queryMap == null) {
					queryMap = loadQueryMap();
					if (queryMapRef.compareAndSet(null, queryMap) == false) {
						queryMap = queryMapRef.get();
					}
				}
			}
		}
		return queryMap.get(queryId);
	}

}
