/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.provider.loader.file;

import java.io.File;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.Map;

import kr.kangwoo.damo.DamoException;
import kr.kangwoo.damo.Messages;
import kr.kangwoo.damo.engine.query.Query;
import kr.kangwoo.util.MessageUtils;

public class SimpleQueryFileLoader extends QueryFileLoader {

	private Map<String, Query> queryMap;
	
	public SimpleQueryFileLoader() {
	}
	
	@Override
	public void init(File[] files) {
		super.init(files);
		queryMap = new HashMap<String, Query>();
		load();
	}

	private void load() throws DamoException {
		queryMap.clear();
		if (queryFiles != null) {
			for (QueryFile queryMapper : queryFiles) {
				Map<String, Query> map = queryMapper.getQueryMap();
				if (map != null) {
					for (String queryId : map.keySet()) {
						if (queryMap.containsKey(queryId)) {
							throw new DamoException(MessageUtils.format(Messages.getString("SimpleQueryFileLoader.DUPLICATED_QUERY_ID"), queryMapper.getFile(), queryId)); //$NON-NLS-1$
						}
						Query query = map.get(queryId);
						queryMap.put(queryId, query);
					}
				}
			}
		}
	}

	public Query getQuery(String queryId) throws SQLException {
		return queryMap.get(queryId);
	}

}
