/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query;

import kr.kangwoo.damo.engine.cache.CacheStrategy;
import kr.kangwoo.damo.engine.executor.interceptor.ExecuteInterceptor;
import kr.kangwoo.damo.engine.executor.interceptor.HandleRowInterceptor;

public abstract class BaseQuery implements Query {
	
	protected CommandType commandType;
	protected String description;
	
	protected ExecuteInterceptor[] executeInterceptors;
	protected HandleRowInterceptor[] handleRowInterceptors;
	
	protected Integer fetchSize;
	protected Integer resultSetType;
	protected Integer resultSetConcurrency;
	
	protected String cacheName;
	protected CacheStrategy cacheStrategy;
	
	public BaseQuery(CommandType commandType, String description) {
		this.commandType = commandType;
		this.description = description;
	}
	
	public CommandType getCommandType() {
		return commandType;
	}
	
	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public void addExecuteInterceptor(ExecuteInterceptor executeInterceptor) {
		if (executeInterceptors == null) {
			executeInterceptors = new ExecuteInterceptor[1];
		} else {
			ExecuteInterceptor[] temp = new ExecuteInterceptor[executeInterceptors.length + 1];
			System.arraycopy(executeInterceptors, 0, temp, 0, executeInterceptors.length);
			executeInterceptors = temp;
		}
		executeInterceptors[executeInterceptors.length - 1] = executeInterceptor;
	}

	
	public ExecuteInterceptor[] getExecuteInterceptors() {
		return executeInterceptors;
	}

	public void setExecuteInterceptors(ExecuteInterceptor[] executeInterceptors) {
		this.executeInterceptors = executeInterceptors;
	}

	public void addHandleRowInterceptor(HandleRowInterceptor handleRowInterceptor) {
		if (handleRowInterceptors == null) {
			handleRowInterceptors = new HandleRowInterceptor[1];
		} else {
			HandleRowInterceptor[] temp = new HandleRowInterceptor[handleRowInterceptors.length + 1];
			System.arraycopy(handleRowInterceptors, 0, temp, 0, handleRowInterceptors.length);
			handleRowInterceptors = temp;
		}
		handleRowInterceptors[handleRowInterceptors.length - 1] = handleRowInterceptor;
	}
	
	public HandleRowInterceptor[] getHandleRowInterceptors() {
		return handleRowInterceptors;
	}

	public void setHandleRowInterceptors(
			HandleRowInterceptor[] handleRowInterceptors) {
		this.handleRowInterceptors = handleRowInterceptors;
	}

	public Integer getFetchSize() {
		return fetchSize;
	}
	
	public void setFetchSize(Integer fetchSize) {
		this.fetchSize = fetchSize;
	}

	public Integer getResultSetType() {
		return resultSetType;
	}

	public void setResultSetType(Integer resultSetType) {
		this.resultSetType = resultSetType;
	}

	public Integer getResultSetConcurrency() {
		return resultSetConcurrency;
	}

	public void setResultSetConcurrency(Integer resultSetConcurrency) {
		this.resultSetConcurrency = resultSetConcurrency;
	}

	public String getCacheName() {
		return cacheName;
	}

	public void setCacheName(String cacheName) {
		this.cacheName = cacheName;
	}

	public CacheStrategy getCacheStrategy() {
		return cacheStrategy;
	}

	public void setCacheStrategy(CacheStrategy cacheStrategy) {
		this.cacheStrategy = cacheStrategy;
	}
	
}
