/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query;

import java.util.ArrayList;
import java.util.List;

import kr.kangwoo.damo.engine.executor.interceptor.ExecuteInterceptor;
import kr.kangwoo.damo.engine.executor.interceptor.HandleRowInterceptor;
import kr.kangwoo.damo.engine.query.parameter.ParameterInfo;
import kr.kangwoo.damo.engine.query.token.StaticToken;
import kr.kangwoo.damo.engine.query.token.Token;

public class DynamicQuery extends BaseQuery {

	private Token[] tokens;

	public DynamicQuery(CommandType commandType, Token[] tokens) {
		this(commandType, tokens, null, null, null);
	}

	public DynamicQuery(CommandType commandType, Token[] tokens, String description) {
		this(commandType, tokens, description, null, null);
	}

	public DynamicQuery(CommandType commandType, Token[] tokens, String description,
			ExecuteInterceptor[] executeInterceptors,
			HandleRowInterceptor[] handleRowInterceptors) {
		super(commandType, description);
		this.tokens = tokens;
		this.executeInterceptors = executeInterceptors;
		this.handleRowInterceptors = handleRowInterceptors;
	}

	public RunnableQuery getRunnableQuery(Object parameterObject) {
		StringBuilder sql = new StringBuilder();
		List<ParameterInfo<?>> parameterInfoList = new ArrayList<ParameterInfo<?>>();
		for (Token token : tokens) {
			StaticToken staticToken = token.getStaticToken(parameterObject);
			if (staticToken != null) {
				String prepend = token.getPrepend();
				if (prepend != null) {
					sql.append(prepend);
				}
				sql.append(staticToken.getSql());
				if (staticToken.getParameterInfos() != null) {
					for (ParameterInfo<?> pm : staticToken.getParameterInfos()) {
						parameterInfoList.add(pm);
					}
				}
			}
		}
		StaticQuery staticQuery = new StaticQuery(commandType, sql.toString(), ParameterInfo.toArray(parameterInfoList), description);
		staticQuery.setFetchSize(fetchSize);
		staticQuery.setResultSetType(resultSetType);
		staticQuery.setResultSetConcurrency(resultSetConcurrency);
		staticQuery.setExecuteInterceptors(executeInterceptors);
		staticQuery.setHandleRowInterceptors(handleRowInterceptors);
		return staticQuery;
	}
}
