/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.parameter.type;

import java.math.BigDecimal;
import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

public class BigDecimalTypeHandler extends BaseTypeHandler<BigDecimal> {

	public void bindParameter(PreparedStatement pstmt, int parameterIndex, BigDecimal parameter)
			throws SQLException {
		pstmt.setBigDecimal(parameterIndex, parameter);
	}
	
	public void registerOutParameter(CallableStatement cstmt,
			int parameterIndex) throws SQLException {
		cstmt.registerOutParameter(parameterIndex, Types.NUMERIC);
	}
	
	public BigDecimal getResult(ResultSet rs, String columnName) throws SQLException {
		BigDecimal result = rs.getBigDecimal(columnName);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public BigDecimal getResult(ResultSet rs, int columnIndex) throws SQLException {
		BigDecimal result = rs.getBigDecimal(columnIndex);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public BigDecimal getResult(CallableStatement cstmt, int columnIndex) throws SQLException {
		BigDecimal result = cstmt.getBigDecimal(columnIndex);
		if (cstmt.wasNull()) {
			return null;
		} else {
			return result;
		}
	}

	public BigDecimal valueOf(String str) {
		return new BigDecimal(str);
	}

	public Class<BigDecimal> getType() {
		return BigDecimal.class;
	}
}
