/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.parameter.type;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.sql.Blob;
import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

import kr.kangwoo.damo.Messages;
import kr.kangwoo.util.MessageUtils;

public class BlobTypeHandler extends BaseTypeHandler<byte[]> {

	public void bindParameter(PreparedStatement pstmt, int parameterIndex, byte[] parameter) throws SQLException {
		if (parameter != null) {
			ByteArrayInputStream input = new ByteArrayInputStream(parameter);
			pstmt.setBinaryStream(parameterIndex, input, parameter.length);
		} else {
			pstmt.setNull(parameterIndex, Types.BLOB);
		}
	}
	
	public void registerOutParameter(CallableStatement cstmt,
			int parameterIndex) throws SQLException {
		cstmt.registerOutParameter(parameterIndex, Types.BLOB);
	}
	
	public byte[] getResult(ResultSet rs, String columnName) throws SQLException {
		Blob blob = rs.getBlob(columnName);
		if (rs.wasNull()) {
			return null;
		} else {
			try {
				return getBytes(blob);
			} catch (IOException e) {
				throw (SQLException)new SQLException(MessageUtils.format(Messages.getString("TypeHandler.GET_VALUE_BY_COLUMN_NAME_ERROR"), columnName)).initCause(e); //$NON-NLS-1$
			}
		}
	}
	
	public byte[] getResult(ResultSet rs, int columnIndex) throws SQLException {
		Blob blob = rs.getBlob(columnIndex);
		if (rs.wasNull()) {
			return null;
		} else {
			try {
				return getBytes(blob);
			} catch (IOException e) {
				throw (SQLException)new SQLException(MessageUtils.format(Messages.getString("TypeHandler.GET_VALUE_BY_COLUMN_INDEX_ERROR"), columnIndex)).initCause(e); //$NON-NLS-1$
			}
		}
	}

	public byte[] getResult(CallableStatement cstmt, int columnIndex) throws SQLException {
		Blob blob = cstmt.getBlob(columnIndex);
		if (cstmt.wasNull()) {
			return null;
		} else {
			try {
				return getBytes(blob);
			} catch (IOException e) {
				throw (SQLException)new SQLException(MessageUtils.format(Messages.getString("TypeHandler.GET_VALUE_BY_COLUMN_INDEX_ERROR"), columnIndex)).initCause(e); //$NON-NLS-1$
			}
		}
	}

	public byte[] valueOf(String str) {
		return str.getBytes();
	}
	
	private byte[] getBytes(Blob blob) throws IOException, SQLException {
		InputStream input = blob.getBinaryStream();
		ByteArrayOutputStream output = new ByteArrayOutputStream();
		byte[] buf = new byte[1024];
		int len = 0;
		while ( (len = input.read(buf)) != -1) {
			output.write(buf, 0, len);
		}
		return output.toByteArray();
	}

	public Class<byte[]> getType() {
		return byte[].class;
	}
}
