/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.parameter.type;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

public class ByteTypeHandler extends BaseTypeHandler<Byte> {

	public void bindParameter(PreparedStatement pstmt, int parameterIndex, Byte parameter)
			throws SQLException {
		if (parameter != null) {
			pstmt.setByte(parameterIndex, parameter);	
		} else {
			pstmt.setNull(parameterIndex, Types.TINYINT);
		}
	}
	
	public void registerOutParameter(CallableStatement cstmt,
			int parameterIndex) throws SQLException {
		cstmt.registerOutParameter(parameterIndex, Types.TINYINT);
	}
	
	public Byte getResult(ResultSet rs, String columnName) throws SQLException {
		Byte result = rs.getByte(columnName);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public Byte getResult(ResultSet rs, int columnIndex) throws SQLException {
		Byte result = rs.getByte(columnIndex);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public Byte getResult(CallableStatement cstmt, int columnIndex) throws SQLException {
		Byte result = cstmt.getByte(columnIndex);
		if (cstmt.wasNull()) {
			return null;
		} else {
			return result;
		}
	}

	public Byte valueOf(String str) {
		return Byte.valueOf(str);
	}
	
	public Class<Byte> getType() {
		return Byte.class;
	}
}
