/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.parameter.type;

import java.io.IOException;
import java.io.Reader;
import java.io.StringReader;
import java.io.StringWriter;
import java.sql.CallableStatement;
import java.sql.Clob;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

import kr.kangwoo.damo.Messages;
import kr.kangwoo.util.MessageUtils;

public class ClobTypeHandler extends BaseTypeHandler<String> {

	public void bindParameter(PreparedStatement pstmt, int parameterIndex, String parameter) throws SQLException {
		if (parameter != null) {
			StringReader reader = new StringReader(parameter);
			pstmt.setCharacterStream(parameterIndex, reader, parameter.length());
		} else {
			pstmt.setNull(parameterIndex, Types.CLOB);
		}
	}
	
	public void registerOutParameter(CallableStatement cstmt,
			int parameterIndex) throws SQLException {
		cstmt.registerOutParameter(parameterIndex, Types.CLOB);
	}
	
	public String getResult(ResultSet rs, String columnName) throws SQLException {
		Clob clob = rs.getClob(columnName);
		if (rs.wasNull()) {
			return null;
		} else {
			try {
				return getString(clob);
			} catch (IOException e) {
				throw (SQLException)new SQLException(MessageUtils.format(Messages.getString("TypeHandler.GET_VALUE_BY_COLUMN_NAME_ERROR"), columnName)).initCause(e); //$NON-NLS-1$
			}
		}
	}
	
	public String getResult(ResultSet rs, int columnIndex) throws SQLException {
		Clob clob = rs.getClob(columnIndex);
		if (rs.wasNull()) {
			return null;
		} else {
			try {
				return getString(clob);
			} catch (IOException e) {
				throw (SQLException)new SQLException(MessageUtils.format(Messages.getString("TypeHandler.GET_VALUE_BY_COLUMN_INDEX_ERROR"), columnIndex)).initCause(e); //$NON-NLS-1$
			}
		}
	}

	public String getResult(CallableStatement cstmt, int columnIndex) throws SQLException {
		Clob clob = cstmt.getClob(columnIndex);
		if (cstmt.wasNull()) {
			return null;
		} else {
			try {
				return getString(clob);
			} catch (IOException e) {
				throw (SQLException)new SQLException(MessageUtils.format(Messages.getString("TypeHandler.GET_VALUE_BY_COLUMN_INDEX_ERROR"), columnIndex)).initCause(e); //$NON-NLS-1$
			}
		}
	}

	public String valueOf(String str) {
		return str;
	}
	
	private String getString(Clob clob) throws IOException, SQLException {
		Reader reader = clob.getCharacterStream();
		StringWriter writer = new StringWriter();
		char[] cbuf = new char[1024];
		int len = 0;
		while ( (len = reader.read(cbuf)) != -1) {
			writer.write(cbuf, 0, len);
		}
		return writer.toString();
	}

	public Class<String> getType() {
		return String.class;
	}
}
