/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.parameter.type;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.sql.Types;
import java.util.HashMap;
import java.util.Map;

public class JdbcTypeRegistry {

	public static final int UNKNOWN_TYPE = Integer.MIN_VALUE;
	public static final String UNKNOWN_TYPE_NAME = "UNKNOWN_TYPE"; //$NON-NLS-1$
	
	private static final Map<String, Integer> TYPE_MAP = new HashMap<String, Integer>();
	private static final Map<Integer, String> REVERSE_TYPE_MAP = new HashMap<Integer, String>();
	
	static {
		Field[] fields = Types.class.getFields();
		if (fields != null) {
			for (Field field : fields) {
				if (field.getType() == int.class && Modifier.isPublic(field.getModifiers())
						&& Modifier.isStatic(field.getModifiers())
						&& Modifier.isFinal(field.getModifiers())) {
					try {
						System.out.println(field.getName() + ", " +  field.getInt(null)); //$NON-NLS-1$
						setType(field.getName(), field.getInt(null));
					} catch (IllegalArgumentException e) {
						// 무시(이론적으로 발생하지 않음)
					} catch (IllegalAccessException e) {
						// 무시(이론적으로 발생하지 않음)
					}
				}
			}
		}
	}
	
	private static void setType(String typeName, int type) {
		TYPE_MAP.put(typeName, type);
		REVERSE_TYPE_MAP.put(type, typeName);
	}
	
	public static int getType(String typeName) {
		if (typeName == null) {
			return UNKNOWN_TYPE;
		}
		Integer type = TYPE_MAP.get(typeName);
		if (type != null) {
			return type.intValue();
		}
		return UNKNOWN_TYPE;
	}
	
	public static String getTypeName(int type) {
		String typeName = REVERSE_TYPE_MAP.get(type);
		if (typeName != null) {
			return typeName;
		}
		return UNKNOWN_TYPE_NAME;
	}
}
