/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.parameter.type;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

public class ShortTypeHandler extends BaseTypeHandler<Short> {

	public void bindParameter(PreparedStatement pstmt, int parameterIndex, Short parameter)
			throws SQLException {
		if (parameter != null) {
			pstmt.setShort(parameterIndex, parameter);	
		} else {
			pstmt.setNull(parameterIndex, Types.SMALLINT);
		}
	}
	
	public void registerOutParameter(CallableStatement cstmt,
			int parameterIndex) throws SQLException {
		cstmt.registerOutParameter(parameterIndex, Types.SMALLINT);
	}
	
	public Short getResult(ResultSet rs, String columnName) throws SQLException {
		Short result = rs.getShort(columnName);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public Short getResult(ResultSet rs, int columnIndex) throws SQLException {
		Short result = rs.getShort(columnIndex);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public Short getResult(CallableStatement cstmt, int columnIndex) throws SQLException {
		Short result = cstmt.getShort(columnIndex);
		if (cstmt.wasNull()) {
			return null;
		} else {
			return result;
		}
	}

	public Short valueOf(String str) {
		return Short.valueOf(str);
	}
	
	public Class<Short> getType() {
		return Short.class;
	}
}
