/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.parameter.type;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Time;
import java.sql.Types;

import kr.kangwoo.util.DateUtils;



public class SqlTimeTypeHandler extends BaseTypeHandler<Time> {

	public void bindParameter(PreparedStatement pstmt, int parameterIndex, Time parameter)
			throws SQLException {
		if (parameter != null) {
			pstmt.setTime(parameterIndex, parameter);	
		} else {
			pstmt.setTime(parameterIndex, null);
		}
	}
	
	public void registerOutParameter(CallableStatement cstmt,
			int parameterIndex) throws SQLException {
		cstmt.registerOutParameter(parameterIndex, Types.TIME);
	}
	
	public Time getResult(ResultSet rs, String columnName) throws SQLException {
		Time result = rs.getTime(columnName);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public Time getResult(ResultSet rs, int columnIndex) throws SQLException {
		Time result = rs.getTime(columnIndex);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public Time getResult(CallableStatement cstmt, int columnIndex) throws SQLException {
		Time result = cstmt.getTime(columnIndex);
		if (cstmt.wasNull()) {
			return null;
		} else {
			return result;
		}
	}

	public Time valueOf(String str) {
		return new Time(DateUtils.toDate(str).getTime());
	}
	
	public Class<Time> getType() {
		return Time.class;
	}
}
