/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.parameter.type;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.sql.Types;

import kr.kangwoo.util.DateUtils;



public class SqlTimestampTypeHandler extends BaseTypeHandler<Timestamp> {

	public void bindParameter(PreparedStatement pstmt, int parameterIndex, Timestamp parameter)
			throws SQLException {
		if (parameter != null) {
			pstmt.setTimestamp(parameterIndex, parameter);	
		} else {
			pstmt.setTimestamp(parameterIndex, null);
		}
	}
	
	public void registerOutParameter(CallableStatement cstmt,
			int parameterIndex) throws SQLException {
		cstmt.registerOutParameter(parameterIndex, Types.TIMESTAMP);
	}
	
	public Timestamp getResult(ResultSet rs, String columnName) throws SQLException {
		Timestamp result = rs.getTimestamp(columnName);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public Timestamp getResult(ResultSet rs, int columnIndex) throws SQLException {
		Timestamp result = rs.getTimestamp(columnIndex);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public Timestamp getResult(CallableStatement cstmt, int columnIndex) throws SQLException {
		Timestamp result = cstmt.getTimestamp(columnIndex);
		if (cstmt.wasNull()) {
			return null;
		} else {
			return result;
		}
	}

	public Timestamp valueOf(String str) {
		return new Timestamp(DateUtils.toDate(str).getTime());
	}
	
	public Class<Timestamp> getType() {
		return Timestamp.class;
	}
}
