/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.parameter.type;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

public class UnknownTypeHandler extends BaseTypeHandler<Object> {
	
	private TypeHandlerFactory typeHandlerFactory;
	
	public UnknownTypeHandler(TypeHandlerFactory typeHandlerFactory) {
		this.typeHandlerFactory = typeHandlerFactory;
	}
	
	private Class<?> getParameterClass(Object parameter) {
		Class<?> parameterClass = parameter.getClass();
		return parameterClass;
	}
	
	@SuppressWarnings("unchecked")
	public void bindParameter(PreparedStatement pstmt, int parameterIndex, Object parameter)
			throws SQLException {
		if (parameter != null) {
			Class<?> parameterClass = getParameterClass(parameter);
			TypeHandler<Object> typeHandler = (TypeHandler<Object>) typeHandlerFactory.getTypeHandler(parameterClass);
			typeHandler.bindParameter(pstmt, parameterIndex, parameter);	
		} else {
			pstmt.setObject(parameterIndex, parameter);
		}
	}

	public void registerOutParameter(CallableStatement cstmt,
			int parameterIndex) throws SQLException {
		cstmt.registerOutParameter(parameterIndex, Types.OTHER);
	}
	
	public Object getResult(ResultSet rs, String columnName) throws SQLException {
		Object result = rs.getObject(columnName);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public Object getResult(ResultSet rs, int columnIndex) throws SQLException {
		Object result = rs.getObject(columnIndex);
		if (rs.wasNull()) {
			return null;
		} else {
			return result;
		}
	}
	
	public Object getResult(CallableStatement cstmt, int columnIndex) throws SQLException {
		Object result = cstmt.getObject(columnIndex);
		if (cstmt.wasNull()) {
			return null;
		} else {
			return result;
		}
	}

	public Object valueOf(String str) {
		return str;
	}
	
	public Class<Object> getType() {
		return Object.class;
	}
}
