/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.result;

import java.util.HashMap;
import java.util.Map;

import kr.kangwoo.damo.DamoException;
import kr.kangwoo.damo.Messages;
import kr.kangwoo.damo.engine.query.parameter.ParameterInfo;
import kr.kangwoo.util.BeanUtils;
import kr.kangwoo.util.MessageUtils;

public class MapRowHandler<K, V> implements RowHandler<V> {

	private Map<K, V> map;
	private String key;
	
	public MapRowHandler(String key) {
		this(key, new HashMap<K, V>());
	}
	
	public MapRowHandler(String key, Map<K, V> map) {
		this.key = key;
		this.map = map;
	}
	
	public void init(ParameterInfo<?>[] outputParameterInfo) {
		
	}
	
	@SuppressWarnings("unchecked")
	public void handleRow(V valueObject) {
		try {
			map.put((K)BeanUtils.getProperty(valueObject, key), valueObject);
		} catch (Exception e) {
			throw new DamoException(MessageUtils.format(Messages.getString("MapRowHandler.GET_PROPERTY_ERROR"), valueObject, key), e); //$NON-NLS-1$
		}
	}

	public Map<K, V> getMap() {
		return map;
	}
}
