/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.token;

import java.util.concurrent.ConcurrentHashMap;

import kr.kangwoo.damo.external.el.ExpressionEvaluator;

/**
 * <p>단순 치환용 조각이다. "@{"로 시작해서 "}"로 끝나는 부분이다.</p>
 * 
 * @author kangwoo
 *
 */
public class ReplaceToken extends BaseToken {
	
	private StaticToken staticToken;
	private String expression;
	
	private ConcurrentHashMap<String, StaticToken> staticTokenMap = new ConcurrentHashMap<String, StaticToken>();

	
	/**
	 * <p>단순 치환용 조각의 생성자이다.</p>
	 * 
	 * @param sql @{TOKEN} 구문의 TOKEN 부분이다.
	 */
	public ReplaceToken(String expression) {
		this.expression = "$" + expression.substring(1); //$NON-NLS-1$
		this.staticToken = new StaticToken(this.expression);
	}

	public StaticToken getStaticToken(Object parameterObject) {
		Object value = ExpressionEvaluator.evaluate("name", expression, Object.class, parameterObject); //$NON-NLS-1$
		if (value != null) {
			String str = String.valueOf(value);
			StaticToken newStaticToken = staticTokenMap.get(str);
			if (newStaticToken == null) {
				newStaticToken = new StaticToken(str, null);
				StaticToken tempStaticToken = staticTokenMap.putIfAbsent(str, newStaticToken);
				if (tempStaticToken != null) {
					newStaticToken = tempStaticToken;
				}
			}
			return newStaticToken;
		} else {
			return staticToken;	
		}
	}

	public String getPrepend() {
		return null;
	}

}
