/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.query.token;

import java.util.ArrayList;
import java.util.List;

import kr.kangwoo.damo.engine.query.parameter.ParameterInfo;

public abstract class SuperToken extends BaseToken {

	
	protected List<Token> subTokenList;
	
	public SuperToken() {
		this(null);
	}
	
	public SuperToken(List<Token> subTokenList) {
		this.subTokenList = subTokenList;
	}

	public void add(Token subToken) {
		if (subTokenList == null) {
			subTokenList = new ArrayList<Token>(); 
		}
		subTokenList.add(subToken);
	}
	
	public void addAll(List<Token> subTokenList) {
		if (this.subTokenList == null) {
			this.subTokenList = new ArrayList<Token>(); 
		}
		this.subTokenList.addAll(subTokenList);
	}
	
	public StaticToken getStaticToken(Object parameterObject) {
		if (subTokenList == null) {
			return null;
		}
		
		if (subTokenList.size() == 1) {
			return subTokenList.get(0).getStaticToken(parameterObject);
		}
		
		StringBuilder sql = new StringBuilder();
		List<ParameterInfo<?>> parameterInfoList = new ArrayList<ParameterInfo<?>>();
		
		String childPrepend;
		for (Token child : subTokenList) {
			StaticToken staticToken = child.getStaticToken(parameterObject);
			if (staticToken != null) {
				childPrepend = child.getPrepend();
				if (sql.length() > 0 && childPrepend != null) {
					sql.append(childPrepend);
				}
				sql.append(staticToken.getSql());
				if (staticToken.getParameterInfos() != null) {
					for (ParameterInfo<?> pm : staticToken.getParameterInfos()) {
						parameterInfoList.add(pm);
					}
				}
			}
		}

		if (sql.length() > 0) {
			return new StaticToken(sql.toString(), ParameterInfo.toArray(parameterInfoList));
		} else {
			return null;
		}
	}

}
