/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.transaction.jta;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.transaction.UserTransaction;

import kr.kangwoo.damo.Messages;
import kr.kangwoo.damo.engine.transaction.BaseTransactionProvider;
import kr.kangwoo.damo.engine.transaction.Transaction;
import kr.kangwoo.damo.engine.transaction.TransactionException;
import kr.kangwoo.util.MessageUtils;

/**
 * JTA 트랜잭션 제공자이다.
 * setUserTransaction(UserTransaction) 메소드를 사용하여 직접적으로 javax.transaction.UserTransaction을 제공해주던지,
 * setUserTransactionName(String) 메소드를 사용하여 JNDI명을 명시해주어야한다.
 * 
 * 
 * @author badnom
 *
 */
public class JtaTransactionProvider extends BaseTransactionProvider {

	private UserTransaction userTransaction;
	
	public JtaTransactionProvider() {
	}
	
	public Transaction newTransaction(int transactionIsolationLevel) throws TransactionException {
		return new JtaTransaction(this, userTransaction, dataSource, transactionIsolationLevel);
	}

	public UserTransaction getUserTransaction() {
		return userTransaction;
	}

	public void setUserTransaction(UserTransaction userTransaction) {
		this.userTransaction = userTransaction;
	}

	public void setUserTransactionName(String userTransactionName) throws TransactionException {
		try {
			InitialContext initCtx = new InitialContext();
			userTransaction = (UserTransaction) initCtx.lookup(userTransactionName);
		} catch (NamingException e) {
			throw new TransactionException(MessageUtils.format(Messages.getString("JtaTransactionProvider.NOT_FOUND_USER_TRANSACTION"), userTransactionName), e); //$NON-NLS-1$
		}
	}
}
