/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.engine.transaction.user;

import java.sql.Connection;
import java.sql.SQLException;

import kr.kangwoo.damo.engine.transaction.BaseTransaction;
import kr.kangwoo.damo.engine.transaction.TransactionException;

/**
 * 사용자 제공  트랜잭션을 구현한다. 
 * 다모(DAMO) 자체의 트랜잭션제공자(TransactionProvider)를 사용하는 것이 아니라, 
 * 사용자가 직접 생성한 java.sql.Conection을 넘겨 받아서 사용한다.
 * 
 * @author badnom
 *
 */
public class UserProvidedTransaction extends BaseTransaction {
	
	private Connection connection;
	
	public UserProvidedTransaction(Connection connection) {
		// 로그 출력을 위한 랩핑
		this.connection = wrapConnection(connection);
	}
	
	public Connection getConnection() throws SQLException, TransactionException {
		return connection;
	}
	
	public void close() throws SQLException, TransactionException {
		connection.close();
	}

	public void commit() throws SQLException, TransactionException {
		connection.commit();
	}

	public void rollback() throws SQLException, TransactionException {
		connection.rollback();
	}

}
