/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.external.el;

import java.util.Map;

import kr.kangwoo.damo.bundled.org.apache.commons.el.Constants;
import kr.kangwoo.damo.bundled.org.apache.commons.el.ELException;
import kr.kangwoo.damo.bundled.org.apache.commons.el.VariableResolver;
import kr.kangwoo.util.BeanUtils;
import kr.kangwoo.util.MessageUtils;

/**
 * 
 * <p>
 * VariableResolver의 구현채로서, 대상 객체에서 해당하는 이름의 값을 읽어오는 역할을 한다.
 * </p>
 * 
 * @author badnom@kangwoo.kr
 **/
public class SimpleVariableResolver implements VariableResolver {

	/**
	 * <p>
	 * 대상 객체에서 이름에 해당하는 값을 가져온다.
	 * </p>
	 * 
	 * @param name 이름
	 * @param obj 대상 객체
	 * @return 이름에 해당하는 값
	 */
	public Object resolveVariable(String name, Object obj) throws ELException {
		if (obj == null) {
			return null;
		}
		if (obj instanceof java.util.Map<?, ?>) {
			Map<?, ?> map = (Map<?, ?>) obj;
			return map.get(name);
		} else {
			try {
				return BeanUtils.getProperty(obj, name);
			} catch (Exception ex) {
				throw new ELException(MessageUtils.format(
						Constants.ERROR_GETTING_PROPERTY, name, obj), ex);
			}
		}
	}
}
