/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.support.dao;

import java.io.File;
import java.sql.SQLException;

import kr.kangwoo.damo.ExtendedExecutor;
import kr.kangwoo.damo.Messages;
import kr.kangwoo.damo.PersistenceManager;
import kr.kangwoo.damo.engine.batch.BatchCallback;
import kr.kangwoo.damo.engine.batch.BatchResult;
import kr.kangwoo.damo.engine.provider.QueryProvider;
import kr.kangwoo.damo.engine.provider.loader.file.QueryFileLoader;
import kr.kangwoo.damo.engine.provider.loader.file.ReloadableQueryFileLoader;
import kr.kangwoo.damo.engine.provider.loader.file.SimpleQueryFileLoader;
import kr.kangwoo.damo.engine.query.Query;
import kr.kangwoo.damo.engine.query.result.RowHandler;
import kr.kangwoo.util.ClassUtils;
import kr.kangwoo.util.MessageUtils;
import kr.kangwoo.util.io.ClassPathResource;
import kr.kangwoo.util.logging.Logger;
import kr.kangwoo.util.logging.LoggerFactory;


public class DaoSupportImpl extends ExtendedExecutor implements DaoSupport {
	
	protected Logger logger = LoggerFactory.getLogger(getClass());
	protected PersistenceManager persistenceManager;
	
	protected QueryFileLoader queryLoader;
	protected String sqlFilename;

	public DaoSupportImpl() {
		this(PersistenceManager.getPersistenceManager(), 0);
	}
	
	public DaoSupportImpl(PersistenceManager persistenceManager) {
		this(persistenceManager, 0);
	}
	
	public DaoSupportImpl(int reloadSeconds) {
		this(PersistenceManager.getPersistenceManager(), reloadSeconds);
	}
	
	public DaoSupportImpl(PersistenceManager persistenceManager, int reloadSeconds) {
		sqlFilename = ClassUtils.getShortClassName(getClass()) + ".xml"; //$NON-NLS-1$
		ClassPathResource resource = new ClassPathResource(sqlFilename,  getClass());
		if (resource.exists()) {
			logger.debug(MessageUtils.format(Messages.getString("DaoSupportImpl.FILE_FOUND"), sqlFilename)); //$NON-NLS-1$
			try {			
				File file = resource.getFile();
				if (reloadSeconds > 0) {
					queryLoader = new ReloadableQueryFileLoader();	
				} else {
					queryLoader = new SimpleQueryFileLoader();	
				}
				queryLoader.init(new File[] {file});
			} catch(Exception ex) {
				logger.debug(MessageUtils.format(Messages.getString("DaoSupportImpl.PARSE_ERROR"), sqlFilename), ex); //$NON-NLS-1$
			}
		}
		persistenceManager.getQueryProvider();
	}

	public int executeUpdate(Query query, Object parameterObject) throws SQLException {
		return persistenceManager.executeUpdate(query, parameterObject);
	}
	
	public <E> void executeQuery(Query query, Object parameterObject, Class<E> resultClass, RowHandler<E> rowHandler) throws SQLException {
		persistenceManager.executeQuery(query, parameterObject, resultClass, rowHandler);
	}
	
	public <E> void executeQuery(Query query, Object parameterObject, Class<E> resultClass, RowHandler<E> rowHandler, int pageNo, int pageSize) throws SQLException {
		persistenceManager.executeQuery(query, parameterObject, resultClass, rowHandler, pageNo, pageSize);
	}
	
	public <E> E executeCallable(Query query, Object parameterObject, Class<E> resultClass) throws SQLException {
		return persistenceManager.executeCallable(query, parameterObject, resultClass);
	}

	public BatchResult executeBatch(BatchCallback batchCallback)
			throws SQLException {
		return persistenceManager.executeBatch(batchCallback);
	}

	public Query getQuery(String queryId) throws SQLException {
		Query query = null;
		if (queryLoader != null) {
			query = queryLoader.getQuery(queryId);
		}
		return (query != null) ? query : getQueryProvider().getQuery(queryId);
	}

	@Override
	public QueryProvider getQueryProvider() {
		return persistenceManager.getQueryProvider();
	}

}
