package kr.kangwoo.damo.support.logging.simple;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.Statement;

import kr.kangwoo.util.BeanUtils;
import kr.kangwoo.util.SystemUtils;
import kr.kangwoo.util.logging.Logger;
import kr.kangwoo.util.logging.LoggerFactory;

public class ConnectionLogProxy implements InvocationHandler {

	private Logger logger = LoggerFactory.getLogger(Connection.class);
	private Logger stmtLogger = LoggerFactory.getLogger(Statement.class);
	
	private Connection connection;
	private String name;
	
	
	public ConnectionLogProxy(Connection connection) {
		this.connection = connection;
		this.name = connection.getClass().getName() + "@" + Integer.toHexString(System.identityHashCode(connection));
	}

	public Object invoke(Object proxy, Method method, Object[] args)
			throws Throwable {
		try {
			if ("prepareStatement".equals(method.getName())) {
				PreparedStatement pstmt = null;
				try {
					pstmt = (PreparedStatement)method.invoke(connection, args);
					if (stmtLogger.isDebugEnabled()) {
						pstmt = PreparedStatementLogProxy.newInstance(pstmt, (String) args[0]);	
					}
				} catch(Throwable t) {
					logger.error(method.getName() + " " + SystemUtils.LINE_SEPARATOR + (String) args[0]);
					throw t;
				}
				return pstmt;
			} else if("createStatement".equals(method.getName())) {
				Statement stmt = (Statement)method.invoke(connection, args);
				if (stmtLogger.isDebugEnabled()) {
					stmt = StatementLogProxy.newInstance(stmt);	
				}
				return stmt;
			} else if ("commit".equals(method.getName())) {
				logger.debug(method.getName() + " " + name);
			} else if ("rollback".equals(method.getName())) {
				logger.debug(method.getName() + " " +  name);
			} else if ("close".equals(method.getName())) {
				logger.debug(method.getName() + " " +  name);
			}
			return method.invoke(connection, args);
		} catch(Throwable t) {
			throw BeanUtils.unwrapThrowable(t);
		}
	}

	
	public Connection getConnection() {
		return connection;
	}
}
