/*
 * Copyright 2002-2009 Team Jaru.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package kr.kangwoo.damo.support.logging.simple;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.sql.ResultSet;

import kr.kangwoo.util.BeanUtils;
import kr.kangwoo.util.logging.Logger;
import kr.kangwoo.util.logging.LoggerFactory;
import kr.kangwoo.util.sql.logging.BaseLogProxy;

public class ResultSetLogProxy extends BaseLogProxy implements InvocationHandler {

	private Logger logger = LoggerFactory.getLogger(ResultSet.class);
	
	private ResultSet resultSet;
	
	private ResultSetLogProxy(ResultSet resultSet) {
		this.resultSet = resultSet;
	}
	
	public Object invoke(Object proxy, Method method, Object[] args)
			throws Throwable {
		try {
			if ("close".equals(method.getName())) {
				if (logger.isDebugEnabled()) {
//					logger.debug(method.getName() + " " + resultSet);
				}
			} else if ("equals".equals(method.getName())) {
				Object obj = args[0];
				if (obj instanceof Proxy) {
					return new Boolean(proxy == obj);
				}
				return Boolean.FALSE;
			} else if ("hashCode".equals(method.getName())) {
				return new Integer(proxy.hashCode());
			}
			return method.invoke(resultSet, args);
		} catch(Throwable t) {
			throw BeanUtils.unwrapThrowable(t);
		}
	}
	
	public ResultSet getResultSet() {
		return resultSet;
	}
	
	public static ResultSet newInstance(ResultSet rs) {
		InvocationHandler handler = new ResultSetLogProxy(rs);
		return (ResultSet)Proxy.newProxyInstance(ResultSet.class.getClassLoader(), new Class[]{ResultSet.class}, handler);
	}
}
