package kr.kangwoo.damo.support.logging.simple;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.HashSet;
import java.util.Set;

import kr.kangwoo.util.BeanUtils;
import kr.kangwoo.util.SystemUtils;
import kr.kangwoo.util.logging.Logger;
import kr.kangwoo.util.logging.LoggerFactory;

public class StatementLogProxy implements InvocationHandler {
	
	private static final Set<String> EXECUTE_METHOD_NAMES = new HashSet<String>();
	
	static {
		EXECUTE_METHOD_NAMES.add("execute");
		EXECUTE_METHOD_NAMES.add("executeUpdate");
		EXECUTE_METHOD_NAMES.add("executeQuery");
	}
	
	private Logger logger = LoggerFactory.getLogger(Statement.class);
	
	private Statement stmt;
	
	private StatementLogProxy(Statement stmt) {
		this.stmt = stmt;
	}
	
	public Object invoke(Object proxy, Method method, Object[] args)
			throws Throwable {
		try {
			if (EXECUTE_METHOD_NAMES.contains(method.getName())) {
				if (logger.isDebugEnabled()) {
					StringBuilder msg = new StringBuilder();
					msg.append(" Executing ").append(stmt).append(SystemUtils.LINE_SEPARATOR);
					msg.append(((String)args[0]));
					logger.debug(msg.toString());
				}
				if ("executeQuery".equals(method.getName())) {
					ResultSet rs = (ResultSet) method.invoke(stmt, args);
					if (rs != null) {
						return ResultSetLogProxy.newInstance(rs);
					} else {
						return null;
					}
				}
			} else if ("getResultSet".equals(method.getName())) {
				ResultSet rs = (ResultSet) method.invoke(stmt, args);
				if (rs != null) {
					return ResultSetLogProxy.newInstance(rs);
				} else {
					return null;
				}
			} else if ("equals".equals(method.getName())) {
				Object obj = args[0];
				if (obj instanceof Proxy) {
					return new Boolean(proxy == obj);
				}
				return Boolean.FALSE;
			} else if ("hashCode".equals(method.getName())) {
				return new Integer(proxy.hashCode());
			} else if ("close".equals(method.getName())) {

			}
			return method.invoke(stmt, args);
		} catch(Throwable t) {
			throw BeanUtils.unwrapThrowable(t);
		}
	}

	public Statement getStatement() {
		return stmt;
	}
	
	public static Statement newInstance(Statement stmt) {
		InvocationHandler handler = new StatementLogProxy(stmt);
		return (PreparedStatement)Proxy.newProxyInstance(Statement.class.getClassLoader(), new Class[]{Statement.class}, handler);
	}
}
